## $Id: export.py 12107 2014-12-01 16:13:12Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""Exporters for student related stuff.
"""
import grok
from waeup.kofa.interfaces import REQUESTED
from kofacustom.nigeria.students.interfaces import (
    INigeriaStudent,
    INigeriaStudentStudyCourse,
    INigeriaStudentStudyLevel,
    INigeriaCourseTicket,
    INigeriaStudentOnlinePayment)
from waeup.kofa.students.export import (
    StudentExporter,
    StudentStudyCourseExporter,
    StudentStudyLevelExporter,
    CourseTicketExporter,
    StudentPaymentsExporter)
from waeup.kofa.utils.helpers import iface_names
from kofacustom.nigeria.interfaces import MessageFactory as _

class NigeriaStudentExporter(StudentExporter):
    """Exporter for Students.
    """

    #: Fieldnames considered by this exporter
    fields = tuple(sorted(iface_names(
        INigeriaStudent, omit=['loggerInfo']))) + (
        'password', 'state', 'history', 'certcode', 'is_postgrad',
        'current_level', 'current_session')

    def mangle_value(self, value, name, context=None):
        if '_result' in name and value:
            value = [eval(entry.to_string()) for entry in value]
        return super(
            NigeriaStudentExporter, self).mangle_value(
            value, name, context=context)

class NigeriaStudentStudyCourseExporter(StudentStudyCourseExporter):
    """Exporter for StudentStudyCourses.
    """

    #: Fieldnames considered by this exporter
    fields = tuple(
        sorted(iface_names(INigeriaStudentStudyCourse))) + ('student_id',)

class NigeriaStudentStudyLevelExporter(StudentStudyLevelExporter):
    """Exporter for StudentStudyLevels.
    """
    #: Fieldnames considered by this exporter
    fields = tuple(sorted(iface_names(
        INigeriaStudentStudyLevel) + ['level'])) + (
        'student_id', 'number_of_tickets','certcode')

class NigeriaCourseTicketExporter(CourseTicketExporter):
    """Exporter for CourseTickets.
    """

    #: Fieldnames considered by this exporter
    fields = tuple(sorted(iface_names(INigeriaCourseTicket) +
        ['level', 'code', 'level_session'])) + ('student_id',
        'certcode', 'display_fullname')

class NigeriaStudentPaymentsExporter(StudentPaymentsExporter):
    """Exporter for OnlinePayment instances.
    """

    #: Fieldnames considered by this exporter
    fields = tuple(
        sorted(iface_names(
            INigeriaStudentOnlinePayment, exclude_attribs=False,
            omit=['display_item']))) + (
            'student_id','state','current_session')

class ClearanceRequestedStudentExporter(StudentExporter):
    """Exporter of data used to assign dates of invitation
    """

    grok.name('clearancerequested')

    fields = ('student_id', 'reg_number', 'display_fullname',
              'state', 'current_session', 'history', 'date_of_invitation')

    title = _(u'Clearance Invitation Data')

    def filter_func(self, x, **kw):
        # We use this method to post-filter students in state
        # 'clearance_requested'
        return [student for student in x if student.state == REQUESTED]

    def mangle_value(self, value, name, context=None):
        if name == 'history':
            # Only show last mesage
            value = value.messages[-1]
        return super(
            StudentExporter, self).mangle_value(
            value, name, context=context)
